Introduction — Balladeer 0.39.0

# Introduction

Thanks for choosing Balladeer for your next writing project!

You will be steering the vessel, of course. All I did was pick the crew. And here they are:

Python

  A popular, elegant, flexible programming language.

SpeechMark

  A simple, expressive dialogue markup system.

TOML

  A structured data format. Highly specified, and widely adopted.

HTML5

  The ultimate syntax for semantic, portable, electronic documents.

CSS3

  Powerful styling rules for layouts, themes and animation.

The challenge I had was to stop this bunch from fighting.

It took me a while to find the right role for each of these special talents. Then I had to put them all together without there being any friction. In the same way a waveguide finds the match between an amplifier and an antenna. Or how a gearbox couples an engine to a loaded axle.

So there was me, five salty seadogs, half a gallon of rum, and three ounces of butter. I gave them their duties, set them to work and now they’re getting along just fine.

If you’re reading this any time after June 2023, we’ll have completed our trials and stand ready for action.

> Balladeer is a great option for every kind of mission.

> - Parser-driven interactive fiction

> - Choice-based game books

> - Multimedia web art

> - Poetry

> - Screenplay

> You’ll find Balladeer simple to handle. And she’ll take you anywhere you want to go.

> —Tundish